@@ -62,6 +62,10 @@ class NavRowData:
     def get_satellites_count(self):
         return self._satellites_count
 
+    def has_all_data(self) -> bool:
+        return self._satellites_count and self._speed_kmh and self._direction_mag \
+               and self._direction_true and self._timestamp
+
 
 class NavParser:
     """ nav_reader is a class implementing methods to read .nav files in NMEA format """
@@ -100,11 +104,13 @@ class NavParser:
                 read_data = f.readlines()
                 for line in read_data:
                     self.process_NMEA_line(line)
+            self.remove_bad_points()
 
     def read_string(self, nmea: str) -> None:
         read_data = nmea.splitlines()
         for line in read_data:
             self.process_NMEA_line(line)
+        self.remove_bad_points()
 
     def process_NMEA_line(self, line):
         lat, long = None, None
@@ -116,7 +122,6 @@ class NavParser:
         sentenceID = data[0][3:]  # $GPGGA -> GGA
 
         if sentenceID == "GGA":
-            timestamp = datetime.strptime(data[1], "%H%M%S.%f")
             lat_before_conversion = float(data[2])
             long_before_conversion = float(data[4])
             lat_dir, long_dir = data[3], data[5]
@@ -127,10 +132,9 @@ class NavParser:
                 self._points[lat, long].set_talkerID(talkerID)
 
             self._points[lat, long].set_satellites_count(int(data[7]))
-            self._points[lat, long].set_timestamp(timestamp)
 
         elif sentenceID == "RMC":
-            timestamp = datetime.strptime(data[1], "%H%M%S.%f")
+            timestamp = datetime.strptime(f"{data[9]} {data[1]}", "%d%m%y %H%M%S.%f")
             lat_before_conversion = float(data[3])
             long_before_conversion = float(data[5])
             speed_kmh = 1.852 * float(data[7])
@@ -155,8 +159,14 @@ class NavParser:
             self._points[lat, long].set_direction_mag(data[3])
             self._points[lat, long].set_speed_kmh(float(data[7]))
 
+    def remove_bad_points(self):
+        self._points = {k: v for k, v in self._points.items() if v.has_all_data()}
+
     def get_points(self) -> dict:  # getter function
         return self._points
 
     def get_most_accurate_point(self) -> NavRowData:
         return max(self._points, key=lambda s: self._points[s].get_satellites_count())
+
+    def get_most_recent_points(self, num_of_points=1):
+        return sorted(self._points, key=lambda s: self._points[s].get_timestamp())[:num_of_points]
